# Code of Conduct - niobot chat rooms

While we try to be nice and relaxed in our chat rooms, there are still a few guidelines
that you must follow when engaging with our community.

For clarification, "chat room" here refers to any method of communication surrounding nio-bot.
This includes, but is not limited to, the Matrix rooms, and GitHub issues.
Read further to see more specific moderation information.

## Ye old rule book

To keep things short and snappy, not every single punishable offense is listed here. Use a bit of
common sense and think, "would I want this in my community?". If not, neither do we.

### 1. Serve a warm and kind environment

Conversations in the niobot chat rooms should strive to be a warm and welcoming place for anyone
and everyone. This means:

* All conversations should be civil and respectful.
* Drama should be taken to direct messages, unless it directly relates to niobot.
* Hurtful language should never be used, under any circumstances, ever. This includes language
that may be hateful, bigoted, or hurtful.
    * Swearing is permitted, under the authority that it is not excessive or directed.
* Messages should have clear intent - tone is difficult to convey over text.
* Respect the people around you.
    * If someone asks you to stop doing something, you should do so.
    If you have an issue with their request, take it up with them directly in direct messages,
    or elsewhere.

### 2. Do not be disruptive

Causing disruption can happen in many forms, but regardless, is entirely unwelcome.
Being disruptive is usually in the form of sending spam, such as large blocks of text, or
several images, but could also be injecting an off-topic conversation.

### 3. Act without malice

Any form of malice is not welcome in the niobot chat rooms. Doing ANYTHING with malice is
completely unacceptable and will be treated as such.
Even if you do not intend malice, if malice is perceived by a group, and you cannot
appropriately explain why it was not such, then it will be treated so.

### 4. The standard "don't be a thorn"

For this, you may want to take a gander at the [Matrix.org code of conduct](https://matrix.org/legal/code-of-conduct/).
Their CoC has a great list of things that you should *not* do here, such as doxxing, harassment, or posting anything NSFW.

Their code of conduct conduct also applies to our chat rooms as it is a great CoC, aside from:

* Contact: see [contact](#contact)
* Application: Their CoC applies to matrix.org, *and* our rooms.
* Affiliation: We are not affiliated with matrix.org, we are simply using their CoC in good faith.

## Moderation

Moderation in niobot matrix rooms is done by the [Draupnir (`@draupnir:nexy7574.co.uk`)](https://github.com/the-draupnir-project/Draupnir)
bot. This bot has the power level to mute, kick, ban, and serverban (ACL) in all niobot rooms.

Our instance of Draupnir is subscribed to the following moderation lists:

* [Matrix.org's ToS banlist](https://matrix.to/#/!tUPwPPmVTaiKXMiijj:matrix.org?via=matrix.org&via=nexy7574.co.uk)
* [Matrix.org's CoC banlist](https://matrix.to/#/!WuBtumawCeOGEieRrp:matrix.org?via=matrix.org&via=nexy7574.co.uk)
* [envs.net's banlist](https://matrix.to/#/!GGuqmQVLNyWASNjVQw:envs.net?via=envs.net)
* [The Community moderation effort (CME) banlist](https://matrix.to/#/!fTjMjIzNKEsFlUIiru:neko.dev?via=neko.dev&via=envs.net&via=matrix.org&via=nexy7574.co.uk)

Meaning, if your homeserver, or your account, is on any of those ban lists, you will not be able to communicate with our Matrix rooms.
Futhermore, we also maintain our own custom ban list, however this is usually only exclusive to us before it is added to the CME.

If you violate the code of conduct, depending on the severity of the infraction, you will receive:

1. A personal warning
2. A temporary mute
3. A kick
4. A ban

Obviously, doing something like posting NSFW images will get you banned straight away, but simply getting into an argument won't.

For other platforms, moderation will be done manually, and as such more harshly.

## Contact

You can contact anyone in the niobot rooms that you see are a moderator (minus bots), however
`@nex` ((me) in most places) is usually the administrator.
You can contact me outside of matrix by looking at the "contact" section of [my website](https://nexy7574.co.uk).
If that is not working, you can send an email to `admin@` (domain can be nexy7574.co.uk or i-am.nexus), but I cannot
guarantee a timely response.
